==> haskell-typed-process-0.2.6.0-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.6.0
visibility:           public
id:                   typed-process-0.2.6.0-I1SH604Zzlh8NQlO3rFi9D
key:                  typed-process-0.2.6.0-I1SH604Zzlh8NQlO3rFi9D
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://haskell-lang.org/library/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>

category:             System
abi:                  50dbabebfec65648180df2f3aec38e99
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-8.10.1/site-local/typed-process-0.2.6.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/typed-process-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/typed-process-0.2.6.0
hs-libraries:         HStyped-process-0.2.6.0-I1SH604Zzlh8NQlO3rFi9D
depends:
    async-2.2.2-27uIoCa55WFKIXfW5skZlp base-4.14.0.0
    bytestring-0.10.10.0 process-1.6.8.2 stm-2.5.0.0
    transformers-0.5.6.2 unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.6.0-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.6.0
visibility:           public
id:                   typed-process-0.2.6.0-hzMhlDK9Wc7FQpr1lj51D
key:                  typed-process-0.2.6.0-hzMhlDK9Wc7FQpr1lj51D
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://haskell-lang.org/library/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>

category:             System
abi:                  26f648dd3dc68659bbdf0fe342fefc30
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-8.10.2/site-local/typed-process-0.2.6.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/typed-process-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/typed-process-0.2.6.0
hs-libraries:         HStyped-process-0.2.6.0-hzMhlDK9Wc7FQpr1lj51D
depends:
    async-2.2.2-56S94E3l2QiIGw0RV500gN base-4.14.1.0
    bytestring-0.10.10.0 process-1.6.9.0 stm-2.5.0.0
    transformers-0.5.6.2 unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
